@@ -593,24 +593,6 @@ class FakeSessionClient(base_client.SessionClient):
         else:
             return (202, {}, self.get_servers_1234()[2])
 
-    def post_os_volumes_boot(self, body, **kw):
-        assert set(body.keys()) <= set(['server', 'os:scheduler_hints'])
-        fakes.assert_has_keys(
-            body['server'],
-            required=['name', 'flavorRef'],
-            optional=['imageRef'])
-
-        # Require one, and only one, of the keys for bdm
-        if 'block_device_mapping' not in body['server']:
-            if 'block_device_mapping_v2' not in body['server']:
-                raise AssertionError(
-                    "missing required keys: 'block_device_mapping'"
-                )
-        elif 'block_device_mapping_v2' in body['server']:
-            raise AssertionError("found extra keys: 'block_device_mapping'")
-
-        return (202, {}, self.get_servers_9012()[2])
-
     def get_servers_1234(self, **kw):
         server = self.get_servers_detail()[2]['servers'][0]
         if self.api_version >= api_versions.APIVersion('2.71'):
